/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

#ifndef SQUID_INCLUDE_GETFULLHOSTNAME_H
#define SQUID_INCLUDE_GETFULLHOSTNAME_H

SQUIDCEXTERN const char *getfullhostname(void);

#endif /* SQUID_INCLUDE_GETFULLHOSTNAME_H */

